"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import google.protobuf.descriptor
import google.protobuf.message
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class SendOtpRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    IDENTIFIER_FIELD_NUMBER: builtins.int
    identifier: builtins.str
    def __init__(
        self,
        *,
        identifier: builtins.str = ...,
    ) -> None: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["identifier", b"identifier"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___SendOtpRequest: typing_extensions.TypeAlias = SendOtpRequest

@typing.final
class SendOtpResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    status: builtins.bool
    def __init__(
        self,
        *,
        status: builtins.bool = ...,
    ) -> None: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["status", b"status"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___SendOtpResponse: typing_extensions.TypeAlias = SendOtpResponse

@typing.final
class VerifyOtpRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    IDENTIFIER_FIELD_NUMBER: builtins.int
    OTP_FIELD_NUMBER: builtins.int
    identifier: builtins.str
    otp: builtins.str
    def __init__(
        self,
        *,
        identifier: builtins.str = ...,
        otp: builtins.str = ...,
    ) -> None: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["identifier", b"identifier", "otp", b"otp"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___VerifyOtpRequest: typing_extensions.TypeAlias = VerifyOtpRequest

@typing.final
class VerifyOtpResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ACCESS_TOKEN_FIELD_NUMBER: builtins.int
    REFRESH_TOKEN_FIELD_NUMBER: builtins.int
    access_token: builtins.str
    refresh_token: builtins.str
    def __init__(
        self,
        *,
        access_token: builtins.str = ...,
        refresh_token: builtins.str = ...,
    ) -> None: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["access_token", b"access_token", "refresh_token", b"refresh_token"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___VerifyOtpResponse: typing_extensions.TypeAlias = VerifyOtpResponse
