syntax = "proto3";

package auth;

service AuthService {
    rpc SendOtp(SendOtpRequest) returns (SendOtpResponse);
    rpc VerifyOtp(VerifyOtpRequest) returns (VerifyOtpResponse);
} 

message SendOtpRequest {
    string identifier = 1;
}

message SendOtpResponse {
    bool status = 1;
}

message VerifyOtpRequest {
    string identifier = 1;
    string otp = 2;
}

message VerifyOtpResponse {
    string access_token = 1;
    string refresh_token = 2;
}