# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: auth.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'auth.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\nauth.proto\x12\x04\x61uth\"$\n\x0eSendOtpRequest\x12\x12\n\nidentifier\x18\x01 \x01(\t\"!\n\x0fSendOtpResponse\x12\x0e\n\x06status\x18\x01 \x01(\x08\"3\n\x10VerifyOtpRequest\x12\x12\n\nidentifier\x18\x01 \x01(\t\x12\x0b\n\x03otp\x18\x02 \x01(\t\"@\n\x11VerifyOtpResponse\x12\x14\n\x0c\x61\x63\x63\x65ss_token\x18\x01 \x01(\t\x12\x15\n\rrefresh_token\x18\x02 \x01(\t2\x83\x01\n\x0b\x41uthService\x12\x36\n\x07SendOtp\x12\x14.auth.SendOtpRequest\x1a\x15.auth.SendOtpResponse\x12<\n\tVerifyOtp\x12\x16.auth.VerifyOtpRequest\x1a\x17.auth.VerifyOtpResponseb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'auth_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_SENDOTPREQUEST']._serialized_start=20
  _globals['_SENDOTPREQUEST']._serialized_end=56
  _globals['_SENDOTPRESPONSE']._serialized_start=58
  _globals['_SENDOTPRESPONSE']._serialized_end=91
  _globals['_VERIFYOTPREQUEST']._serialized_start=93
  _globals['_VERIFYOTPREQUEST']._serialized_end=144
  _globals['_VERIFYOTPRESPONSE']._serialized_start=146
  _globals['_VERIFYOTPRESPONSE']._serialized_end=210
  _globals['_AUTHSERVICE']._serialized_start=213
  _globals['_AUTHSERVICE']._serialized_end=344
# @@protoc_insertion_point(module_scope)
